==> phpicalendar-2.1.tgz: phpicalendar/languages/finnish.inc.php <==
<?php

// Finnish language include
// For version 1.0 PHP iCalendar
// Translation by Kari Somby (kari.somby@pp.inet.fi)
//
// Revice for version 2.0.1 PHP iCalendar
// Text and script update by Matti Monnonen (matti@monnonen.com)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day']			= 'P&auml;iv&auml;';
$lang['l_week']			= 'Viikko';
$lang['l_month']		= 'Kuukausi';
$lang['l_year']			= 'Vuosi';
$lang['l_calendar']		= 'Kalenteri';
$lang['l_next_day']		= 'Seuraava P&auml;iv&auml;';
$lang['l_next_month']		= 'Seuraava Kuukausi';
$lang['l_next_week']		= 'Seuraava Viikko';
$lang['l_next_year']		= 'Seuraava Vuosi';
$lang['l_last_day']		= 'Edellinen P&auml;iv&auml;';
$lang['l_last_month']		= 'Edellinen Kuukausi';
$lang['l_last_week']		= 'Edellinen Viikko';
$lang['l_last_year']		= 'Edellinen Vuosi';
$lang['l_subscribe']		= 'Kopioi kalenteri';
$lang['l_download']		= 'Lataa tiedosto';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event']		= 'Tapahtuma';
$lang['l_event_start']		= 'Aloitusaika';
$lang['l_event_end']		= 'Lopetusaika';
$lang['l_this_months']		= 'T&auml;m&auml;n Kuukauden tapahtumat';
$lang['l_date']			= 'P&auml;iv&auml;';
$lang['l_summary']		= 'Yhteenveto';
$lang['l_all_day']		= 'Koko p&auml;iv&auml;n tapahtuma';
$lang['l_notes']		= 'Muistiinpanot';
$lang['l_this_years']		= 'T&auml;m&auml;n Vuoden tapahtumat';
$lang['l_today']		= 'T&auml;n&auml;&auml;n';
$lang['l_this_week']		= 'T&auml;m&auml; Viikko';
$lang['l_this_month']		= 'T&auml;m&auml; Kuukausi';
$lang['l_jump']			= 'Siirry';
$lang['l_tomorrows']		= 'Huomisen Tapahtumat';
$lang['l_goday']		= 'Mene T&auml;h&auml;n P&auml;iv&auml;&auml;n';
$lang['l_goweek']		= 'Mene T&auml;h&auml;n Viikkoon';
$lang['l_gomonth']		= 'Mene T&auml;h&auml;n Kuukauteen';
$lang['l_goyear']		= 'Mene T&auml;h&auml;n Vuoteen';
$lang['l_search']		= 'Etsi'; // the verb
$lang['l_results']		= 'Etsinn&auml;n Tulokset';
$lang['l_query']		= 'Kysely'; // will be followed by the search query
$lang['l_no_results']		= 'Tapahtumia ei l&ouml;ytynyt';
$lang['l_goprint']		= 'Tulostettava versio';
$lang['l_time']			= 'Aika';
$lang['l_summary']		= 'Yhteenveto';
$lang['l_description']		= 'Selitys';
$lang['l_this_site_is']		= 'T&auml;m&auml; sivusto on';
$lang['l_no_events_day']	= 'Ei tapahtumia t&auml;n&auml;&auml;n.';
$lang['l_no_events_week']	= 'Ei tapahtumia t&auml;ll&auml; viikolla.';
$lang['l_no_events_month']	= 'Ei tapahtumia t&auml;ss&auml; kuussa.';
$lang['l_rss_day']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date']	= '%b %e';  // Lists just the day
$lang['l_rss_month_date']	= '%b %e';  // Lists just the day
$lang['l_rss_language']		= 'fi-fi';
$lang['l_search_took']		= 'Etsimiseen meni %s sekuntia';
$lang['l_recurring_event']	= 'Toistuva tapahtuma';
$lang['l_exception']		= 'Poikkeus';
$lang['l_no_query']		= 'Kysely&auml; ei annettu';
$lang['l_preferences']		= 'Ominaisuudet';
$lang['l_printer']		= 'Tulostin';
$lang['l_select_lang']		= 'Valitse oletuskieli:';
$lang['l_select_cal']		= 'Valitse oletuskalenteri:';
$lang['l_select_view']		= 'Valitse oletusn&auml;kym&auml;:';
$lang['l_select_time']		= 'Valitse oletusaloitusaika:';
$lang['l_select_day']		= 'Valitse oletusaloitusp&auml;iv&auml; viikolle:';
$lang['l_select_style']		= 'Valitse oletustyyli:';
$lang['l_t_prefs']		= 'Aseta ominaisuudet';
$lang['l_completed_date']	= 'Valmistuu';
$lang['l_completed']		= 'Valmis';
$lang['l_created']		= 'Luotu:';
$lang['l_due']			= 'Er&auml;&auml;ntyy:';
$lang['l_priority']		= 'T&auml;rkeys:';
$lang['l_priority_high']	= 'Korkea';
$lang['l_priority_low']		= 'Matala';
$lang['l_priority_medium']	= 'Keski';
$lang['l_priority_none']	= 'Ei mit&auml;&auml;n';
$lang['l_status']		= 'Tila';
$lang['l_todo']			= 'Teht&auml;v&auml;t:';
$lang['l_unfinished']		= 'P&auml;&auml;ttym&auml;tt&ouml;m&auml;t';
$lang['l_unfinished']		= 'P&auml;&auml;ttym&auml;tt&ouml;m&auml;t';
$lang['l_prefs_set'] 		= 'Asetukset p&auml;ivitetty';
$lang['l_prefs_unset'] 		= 'Asetuksia ei p&auml;ivitetty. Muutokset p&auml;ivitet&auml;&auml;n seuraavan sivun ladattua';
$lang['l_unset_prefs'] 		= 'Asetukset peruttu';
$lang['l_organizer']		= 'Organisoija';
$lang['l_attendee']		= 'Osanottajat';
$lang['l_location']		= 'Paikka';
$lang['l_admin_header']		= 'PHP iCalendar Hallinta';
$lang['l_username']		= 'K&auml;ytt&auml;j&auml;tunnus';
$lang['l_password']		= 'Salasana';
$lang['l_login']		= 'Kirjaudu sis&auml;&auml;n';
$lang['l_invalid_login']	= 'V&auml;&auml;r&auml; k&auml;ytt&auml;j&auml;tunnus tai salasana.';
$lang['l_addupdate_cal']	= 'Lis&auml&auml; tai p&auml;ivit&auml; kalenteri';
$lang['l_addupdate_desc']	= 'Lis&auml&auml; kalenteri lataamalla uusi tiedosto. P&aumlivit&auml kalenteri samannimisell&auml tiedostolla';
$lang['l_delete_cal']		= 'Tuhoa kalenteri';
$lang['l_logout']		= 'Kirjaudu ulos';
$lang['l_cal_file']		= 'Kalenteritiedosto';
$lang['l_php_error']		= 'PHP virhe';
$lang['l_upload_error_gen']	= 'Tiedoston latauksessa oli ongelma.';
$upload_error_lang[0]		= 'Tiedoston latauksessa oli ongelma.';
$upload_error_lang[1]		= 'Ladattavan tiedoston koko on liian suuri.';
$upload_error_lang[2]		= 'Ladattavan tiedoston koko on liian suuri';
$upload_error_lang[3]		= 'Tiedoston lataus onnistui vain osittain.';
$upload_error_lang[4]		= 'Valitse ladattava tiedosto.';
$lang['l_upload_error_type'] 	= 'Voit ladata vain .ics tiedostoja.';
$lang['l_copy_error']		= 'Tiedoston kopiointi ep&auml;onnistui.';
$lang['l_delete_error']		= 'Tiedoston tuhoaminen ep&auml;onnistui.';
$lang['l_delete_success']	= 'Tuhoaminen onnistui.';
$lang['l_action_success']	= 'Toiminta onnistui.';
$lang['l_submit']		= 'L&auml;het&auml;';
$lang['l_delete']		= 'Tuhoa';

// ----- New for 0.9.5
$all_cal_comb_lang              = 'Kaikki yhdistettyn&auml;';

// ---- New for 2.0.1
$lang['l_legend']		= 'Otsikko';
$lang['l_admin_subhead']	= 'Kalenterin hallinta sivu';
$lang['l_prefs_subhead']	= 'Keksin asetukset vierailijoille';
$lang['l_rss_info']		= 'RSS Tiedot';
$lang['l_rss_subhead']		= 'Perus RSS tiedot jokaiselle kalenterille';
$lang['l_rss_notenabled']	= 'RSS ei ole k&auml;yt&ouml;ss&auml; t&auml;ll&auml; sivulla';



// - navigation
$lang['l_back'] 		= 'Takaisin';
$lang['l_next'] 		= 'Seuraava';
$lang['l_prev'] 		= 'Edellinen';
$lang['l_day_view'] 		= 'P&auml;iv&auml;n&auml;kym&auml;';
$lang['l_week_view'] 		= 'Viikkon&auml;kym&auml;';
$lang['l_month_view'] 		= 'Kuukausin&auml;kym&auml;';
$lang['l_year_view'] 		= 'Vuosin&auml;kym&auml;';

// ---------------------------------




// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';						// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('vuosi','vuotta');		// for these, put singular
$format_recur_lang['monthly']		= array('kuukausi','kuukautta');	// and plural forms
$format_recur_lang['weekly']		= array('viikko','viikkoa');		// these will be %freq%
$format_recur_lang['daily']		= array('p&auml;iv&auml;','p&auml;iv&auml;&auml;');			// in the replacement below
$format_recur_lang['hourly']		= array('tunti','tuntia');
$format_recur_lang['minutely']		= array('minuutti','minuuttia');
$format_recur_lang['secondly']		= array('sekuntti','sekunttia');

$format_recur_lang['start']		= 'Joka %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']		= '%date% asti';		// ie, 'until January 4'
$format_recur_lang['count']		= '%int% kertaa';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'Kuukaudet: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['byday']		= 'Viikonp&auml;iv&auml;t: %list%';	// ie, 'On days: Mon, Tues, Wed, Thurs'

$daysofweek_lang			= array ('Sunnuntai','Maanantai','Tiistai','Keskiviikko','Torstai','Perjantai','Lauantai');
$daysofweekshort_lang			= array ('Su','Ma','Ti','Ke','To','Pe','La');
$daysofweekreallyshort_lang		= array ('S','M','T','K','T','P','L');
$monthsofyear_lang			= array ('Tammikuu','Helmikuu','Maaliskuu','Huhtikuu','Toukokuu','Kes&auml;kuu','Hein&auml;kuu','Elokuu','Syyskuu','Lokakuu','Marraskuu','Joulukuu');
$monthsofyearshort_lang			= array ('Tammi','Helmi','Maalis','Huhti','Touko','Kes&auml;','Hein&auml;','Elo','Syys','Loka','Marras','Joulu');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
//$timeFormat 		= 'g:i A';
$timeFormat 		= 'H:i';
$timeFormat_small 	= 'H:i';

// For date formatting, see note below
$dateFormat_day 	= '%A, %e %Bta';
$dateFormat_week 	= '%e %B';
$dateFormat_week_list 	= '%a, %e %b';
$dateFormat_week_jump 	= '%b %e';
$dateFormat_month 	= '%B %Y';
$dateFormat_month_list 	= '%A, %B %e';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Virhe!';
$lang['l_error_window'] 		= 'Tapahtui virhe!';
$lang['l_error_calendar'] 		= 'Kalenteria "%s" k&auml;siteltiin virheen sattuessa.';
$lang['l_error_path'] 			= 'Polkua: "%s" ei voi avata';
$lang['l_error_back'] 			= 'Ole hyv&auml; ja k&auml;yt&auml; "Takaisin" nappia palataksesi takaisin.';
$lang['l_error_remotecal'] 		= 'T&auml;m&auml; palvelin sallii vain hyv&auml;ksyttyjen et&auml;kalentereiden k&auml;yt&ouml;n.';
$lang['l_error_restrictedcal'] 		= 'Yritit k&auml;ytt&auml;&auml; kalenteria, jonka k&auml;ytt&ouml; on rajoitettu.';
$lang['l_error_invalidcal'] 		= 'Ei kelvollinen kalenterin nimi. Ole hyv&auml; ja yrit&auml; toista kalenteria.';

?>

==> phpicalendar-2.31.tgz: phpicalendar/languages/finnish.inc.php <==
<?php

// Finnish language include
// For version 1.0 PHP iCalendar
// Translation by Kari Somby (kari.somby@pp.inet.fi)
//
// Revice for version 2.0.1 PHP iCalendar
// Text and script update by Matti Monnonen (matti@monnonen.com)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day']			= 'P&auml;iv&auml;';
$lang['l_week']			= 'Viikko';
$lang['l_month']		= 'Kuukausi';
$lang['l_year']			= 'Vuosi';
$lang['l_calendar']		= 'Kalenteri';
$lang['l_next_day']		= 'Seuraava P&auml;iv&auml;';
$lang['l_next_month']		= 'Seuraava Kuukausi';
$lang['l_next_week']		= 'Seuraava Viikko';
$lang['l_next_year']		= 'Seuraava Vuosi';
$lang['l_last_day']		= 'Edellinen P&auml;iv&auml;';
$lang['l_last_month']		= 'Edellinen Kuukausi';
$lang['l_last_week']		= 'Edellinen Viikko';
$lang['l_last_year']		= 'Edellinen Vuosi';
$lang['l_subscribe']		= 'Kopioi kalenteri';
$lang['l_download']		= 'Lataa tiedosto';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event']		= 'Tapahtuma';
$lang['l_event_start']		= 'Aloitusaika';
$lang['l_event_end']		= 'Lopetusaika';
$lang['l_this_months']		= 'T&auml;m&auml;n Kuukauden tapahtumat';
$lang['l_date']			= 'P&auml;iv&auml;';
$lang['l_summary']		= 'Yhteenveto';
$lang['l_all_day']		= 'Koko p&auml;iv&auml;n tapahtuma';
$lang['l_notes']		= 'Muistiinpanot';
$lang['l_this_years']		= 'T&auml;m&auml;n Vuoden tapahtumat';
$lang['l_today']		= 'T&auml;n&auml;&auml;n';
$lang['l_this_week']		= 'T&auml;m&auml; Viikko';
$lang['l_this_month']		= 'T&auml;m&auml; Kuukausi';
$lang['l_jump']			= 'Siirry';
$lang['l_tomorrows']		= 'Huomisen Tapahtumat';
$lang['l_goday']		= 'Mene T&auml;h&auml;n P&auml;iv&auml;&auml;n';
$lang['l_goweek']		= 'Mene T&auml;h&auml;n Viikkoon';
$lang['l_gomonth']		= 'Mene T&auml;h&auml;n Kuukauteen';
$lang['l_goyear']		= 'Mene T&auml;h&auml;n Vuoteen';
$lang['l_search']		= 'Etsi'; // the verb
$lang['l_results']		= 'Etsinn&auml;n Tulokset';
$lang['l_pick_multiple'] 	= 'Pick multiple';
$lang['l_query']		= 'Kysely'; // will be followed by the search query
$lang['l_no_results']		= 'Tapahtumia ei l&ouml;ytynyt';
$lang['l_goprint']		= 'Tulostettava versio';
$lang['l_time']			= 'Aika';
$lang['l_summary']		= 'Yhteenveto';
$lang['l_description']		= 'Selitys';
$lang['l_this_site_is']		= 'T&auml;m&auml; sivusto on';
$lang['l_no_events_day']	= 'Ei tapahtumia t&auml;n&auml;&auml;n.';
$lang['l_no_events_week']	= 'Ei tapahtumia t&auml;ll&auml; viikolla.';
$lang['l_no_events_month']	= 'Ei tapahtumia t&auml;ss&auml; kuussa.';
$lang['l_rss_day']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date']	= '%b %e';  // Lists just the day
$lang['l_rss_month_date']	= '%b %e';  // Lists just the day
$lang['l_rss_language']		= 'fi-fi';
$lang['l_search_took']		= 'Etsimiseen meni %s sekuntia';
$lang['l_recurring_event']	= 'Toistuva tapahtuma';
$lang['l_exception']		= 'Poikkeus';
$lang['l_no_query']		= 'Kysely&auml; ei annettu';
$lang['l_preferences']		= 'Ominaisuudet';
$lang['l_printer']		= 'Tulostin';
$lang['l_select_lang']		= 'Valitse oletuskieli:';
$lang['l_select_cal']		= 'Valitse oletuskalenteri:';
$lang['l_select_view']		= 'Valitse oletusn&auml;kym&auml;:';
$lang['l_select_time']		= 'Valitse oletusaloitusaika:';
$lang['l_select_day']		= 'Valitse oletusaloitusp&auml;iv&auml; viikolle:';
$lang['l_select_style']		= 'Valitse oletustyyli:';
$lang['l_t_prefs']		= 'Aseta ominaisuudet';
$lang['l_completed_date']	= 'Valmistuu';
$lang['l_completed']		= 'Valmis';
$lang['l_created']		= 'Luotu:';
$lang['l_due']			= 'Er&auml;&auml;ntyy:';
$lang['l_priority']		= 'T&auml;rkeys:';
$lang['l_priority_high']	= 'Korkea';
$lang['l_priority_low']		= 'Matala';
$lang['l_priority_medium']	= 'Keski';
$lang['l_priority_none']	= 'Ei mit&auml;&auml;n';
$lang['l_status']		= 'Tila';
$lang['l_status_confirmed'] = 'CONFIRMED' ; 
$lang['l_status_cancelled'] = 'CANCELLED'; 
$lang['l_status_tentative'] = 'TENTATIVE'; 
$lang['l_todo']			= 'Teht&auml;v&auml;t:';
$lang['l_unfinished']		= 'P&auml;&auml;ttym&auml;tt&ouml;m&auml;t';
$lang['l_unfinished']		= 'P&auml;&auml;ttym&auml;tt&ouml;m&auml;t';
$lang['l_prefs_set'] 		= 'Asetukset p&auml;ivitetty';
$lang['l_prefs_unset'] 		= 'Asetuksia ei p&auml;ivitetty. Muutokset p&auml;ivitet&auml;&auml;n seuraavan sivun ladattua';
$lang['l_unset_prefs'] 		= 'Asetukset peruttu';
$lang['l_organizer']		= 'Organisoija';
$lang['l_attendee']		= 'Osanottajat';
$lang['l_location']		= 'Paikka';
$lang['l_admin_header']		= 'PHP iCalendar Hallinta';
$lang['l_username']		= 'K&auml;ytt&auml;j&auml;tunnus';
$lang['l_password']		= 'Salasana';
$lang['l_login']		= 'Kirjaudu sis&auml;&auml;n';
$lang['l_invalid_login']	= 'V&auml;&auml;r&auml; k&auml;ytt&auml;j&auml;tunnus tai salasana.';
$lang['l_addupdate_cal']	= 'Lis&auml&auml; tai p&auml;ivit&auml; kalenteri';
$lang['l_addupdate_desc']	= 'Lis&auml&auml; kalenteri lataamalla uusi tiedosto. P&aumlivit&auml kalenteri samannimisell&auml tiedostolla';
$lang['l_delete_cal']		= 'Tuhoa kalenteri';
$lang['l_logout']		= 'Kirjaudu ulos';
$lang['l_cal_file']		= 'Kalenteritiedosto';
$lang['l_php_error']		= 'PHP virhe';
$lang['l_upload_error_gen']	= 'Tiedoston latauksessa oli ongelma.';
$upload_error_lang[0]		= 'Tiedoston latauksessa oli ongelma.';
$upload_error_lang[1]		= 'Ladattavan tiedoston koko on liian suuri.';
$upload_error_lang[2]		= 'Ladattavan tiedoston koko on liian suuri';
$upload_error_lang[3]		= 'Tiedoston lataus onnistui vain osittain.';
$upload_error_lang[4]		= 'Valitse ladattava tiedosto.';
$lang['l_upload_error_type'] 	= 'Voit ladata vain .ics tiedostoja.';
$lang['l_copy_error']		= 'Tiedoston kopiointi ep&auml;onnistui.';
$lang['l_delete_error']		= 'Tiedoston tuhoaminen ep&auml;onnistui.';
$lang['l_delete_success']	= 'Tuhoaminen onnistui.';
$lang['l_action_success']	= 'Toiminta onnistui.';
$lang['l_submit']		= 'L&auml;het&auml;';
$lang['l_delete']		= 'Tuhoa';

// ----- New for 0.9.5
$all_cal_comb_lang              = 'Kaikki yhdistettyn&auml;';

// ---- New for 2.0.1
$lang['l_legend']		= 'Otsikko';
$lang['l_admin_subhead']	= 'Kalenterin hallinta sivu';
$lang['l_prefs_subhead']	= 'Keksin asetukset vierailijoille';
$lang['l_rss_info']		= 'RSS Tiedot';
$lang['l_rss_subhead']		= 'Perus RSS tiedot jokaiselle kalenterille';
$lang['l_rss_notenabled']	= 'RSS ei ole k&auml;yt&ouml;ss&auml; t&auml;ll&auml; sivulla';



// - navigation
$lang['l_back'] 		= 'Takaisin';
$lang['l_next'] 		= 'Seuraava';
$lang['l_prev'] 		= 'Edellinen';
$lang['l_day_view'] 		= 'P&auml;iv&auml;n&auml;kym&auml;';
$lang['l_week_view'] 		= 'Viikkon&auml;kym&auml;';
$lang['l_month_view'] 		= 'Kuukausin&auml;kym&auml;';
$lang['l_year_view'] 		= 'Vuosin&auml;kym&auml;';

// ---------------------------------




// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';						// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('vuosi','vuotta');		// for these, put singular
$format_recur_lang['monthly']		= array('kuukausi','kuukautta');	// and plural forms
$format_recur_lang['weekly']		= array('viikko','viikkoa');		// these will be %freq%
$format_recur_lang['daily']		= array('p&auml;iv&auml;','p&auml;iv&auml;&auml;');			// in the replacement below
$format_recur_lang['hourly']		= array('tunti','tuntia');
$format_recur_lang['minutely']		= array('minuutti','minuuttia');
$format_recur_lang['secondly']		= array('sekuntti','sekunttia');

$format_recur_lang['start']		= 'Joka %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']		= '%date% asti';		// ie, 'until January 4'
$format_recur_lang['count']		= '%int% kertaa';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'Kuukaudet: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['byday']		= 'Viikonp&auml;iv&auml;t: %list%';	// ie, 'On days: Mon, Tues, Wed, Thurs'

$daysofweek_lang			= array ('Sunnuntai','Maanantai','Tiistai','Keskiviikko','Torstai','Perjantai','Lauantai');
$daysofweekshort_lang			= array ('Su','Ma','Ti','Ke','To','Pe','La');
$daysofweekreallyshort_lang		= array ('S','M','T','K','T','P','L');
$monthsofyear_lang			= array ('Tammikuu','Helmikuu','Maaliskuu','Huhtikuu','Toukokuu','Kes&auml;kuu','Hein&auml;kuu','Elokuu','Syyskuu','Lokakuu','Marraskuu','Joulukuu');
$monthsofyearshort_lang			= array ('Tammi','Helmi','Maalis','Huhti','Touko','Kes&auml;','Hein&auml;','Elo','Syys','Loka','Marras','Joulu');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
//$timeFormat 		= 'g:i A';
$timeFormat 		= 'H:i';
$timeFormat_small 	= 'H:i';

// For date formatting, see note below
$dateFormat_day 	= '%A, %e %Bta';
$dateFormat_week 	= '%e %B';
$dateFormat_week_list 	= '%a, %e %b';
$dateFormat_week_jump 	= '%b %e';
$dateFormat_month 	= '%B %Y';
$dateFormat_month_list 	= '%A, %B %e';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Virhe!';
$lang['l_error_window'] 		= 'Tapahtui virhe!';
$lang['l_error_calendar'] 		= 'Kalenteria "%s" k&auml;siteltiin virheen sattuessa.';
$lang['l_error_path'] 			= 'Polkua: "%s" ei voi avata';
$lang['l_error_back'] 			= 'Ole hyv&auml; ja k&auml;yt&auml; "Takaisin" nappia palataksesi takaisin.';
$lang['l_error_remotecal'] 		= 'T&auml;m&auml; palvelin sallii vain hyv&auml;ksyttyjen et&auml;kalentereiden k&auml;yt&ouml;n.';
$lang['l_error_restrictedcal'] 		= 'Yritit k&auml;ytt&auml;&auml; kalenteria, jonka k&auml;ytt&ouml; on rajoitettu.';
$lang['l_error_invalidcal'] 		= 'Ei kelvollinen kalenterin nimi. Ole hyv&auml; ja yrit&auml; toista kalenteria.';

?>
